@@ -58,9 +58,6 @@ describe 'keystone' do
       'signing_key_size'                   => '<SERVICE DEFAULT>',
       'default_transport_url'              => '<SERVICE DEFAULT>',
       'notification_transport_url'         => '<SERVICE DEFAULT>',
-      'rabbit_host'                        => '<SERVICE DEFAULT>',
-      'rabbit_password'                    => '<SERVICE DEFAULT>',
-      'rabbit_userid'                      => '<SERVICE DEFAULT>',
       'rabbit_heartbeat_timeout_threshold' => '<SERVICE DEFAULT>',
       'rabbit_heartbeat_rate'              => '<SERVICE DEFAULT>',
       'admin_workers'                      => 20,
@@ -91,7 +88,7 @@ describe 'keystone' do
       'revoke_driver'                      => 'kvs',
       'revoke_by_id'                       => false,
       'public_endpoint'                    => 'https://localhost:5000/v2.0/',
-      'admin_endpoint'                     => 'https://localhost:35357/v2.0/',
+      'admin_endpoint'                     => 'https://localhost:5000/v2.0/',
       'enable_ssl'                         => true,
       'ssl_certfile'                       => '/etc/keystone/ssl/certs/keystone.pem',
       'ssl_keyfile'                        => '/etc/keystone/ssl/private/keystonekey.pem',
@@ -111,9 +108,6 @@ describe 'keystone' do
       'signing_key_size'                   => 2048,
       'default_transport_url'              => 'rabbit://user:pass@host:1234/virt',
       'notification_transport_url'         => 'rabbit://user:pass@host:1234/virt',
-      'rabbit_host'                        => '127.0.0.1',
-      'rabbit_password'                    => 'openstack',
-      'rabbit_userid'                      => 'admin',
       'rabbit_heartbeat_timeout_threshold' => '60',
       'rabbit_heartbeat_rate'              => '10',
       'rabbit_ha_queues'                   => true,
@@ -230,10 +224,6 @@ describe 'keystone' do
       end
     end
 
-    it 'should contain correct rabbit_password' do
-      is_expected.to contain_keystone_config('oslo_messaging_rabbit/rabbit_password').with_value(param_hash['rabbit_password']).with_secret(true)
-    end
-
     it 'should contain correct default transport url' do
       is_expected.to contain_keystone_config('DEFAULT/transport_url').with_value(params['default_transport_url'])
     end
@@ -595,10 +585,17 @@ describe 'keystone' do
     it { is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('1000') }
     it { is_expected.to contain_keystone_config('cache/memcache_pool_unused_timeout').with_value('60') }
     it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER1:11211,SERVER2:11211') }
-    it { is_expected.to contain_package('python-memcache').with(
-      :name   => 'python-memcache',
-      :ensure => 'present'
-    ) }
+    it {
+      if facts[:os_package_type] == 'debian'
+        pkg = 'python3-memcache'
+      else
+        pkg = 'python-memcache'
+      end
+      is_expected.to contain_package('python-memcache').with(
+        :name   => pkg,
+        :ensure => 'present'
+      )
+    }
   end
 
   describe 'configure cache memcache servers if set' do
@@ -713,7 +710,7 @@ describe 'keystone' do
         'admin_token'     => 'service_token',
         'enable_ssl'      => true,
         'public_endpoint' => 'https://localhost:5000/v2.0/',
-        'admin_endpoint'  => 'https://localhost:35357/v2.0/',
+        'admin_endpoint'  => 'https://localhost:5000/v2.0/',
       }
     end
     it {is_expected.to contain_keystone_config('ssl/enable').with_value(true)}
@@ -723,7 +720,7 @@ describe 'keystone' do
     it {is_expected.to contain_keystone_config('ssl/ca_key').with_value('/etc/keystone/ssl/private/cakey.pem')}
     it {is_expected.to contain_keystone_config('ssl/cert_subject').with_value('/C=US/ST=Unset/L=Unset/O=Unset/CN=localhost')}
     it {is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value('https://localhost:5000/v2.0/')}
-    it {is_expected.to contain_keystone_config('DEFAULT/admin_endpoint').with_value('https://localhost:35357/v2.0/')}
+    it {is_expected.to contain_keystone_config('DEFAULT/admin_endpoint').with_value('https://localhost:5000/v2.0/')}
   end
   describe 'when disabling SSL' do
     let :params do
@@ -871,15 +868,15 @@ describe 'keystone' do
       {
         :admin_token       => 'service_token',
         :validate_service  => true,
-        :validate_auth_url => 'http://some.host:35357/v2.0',
-        :admin_endpoint    => 'http://some.host:35357'
+        :validate_auth_url => 'http://some.host:5000/v2.0',
+        :admin_endpoint    => 'http://some.host:5000'
       }
     end
 
-    it { is_expected.to contain_keystone_config('DEFAULT/admin_endpoint').with_value('http://some.host:35357') }
+    it { is_expected.to contain_keystone_config('DEFAULT/admin_endpoint').with_value('http://some.host:5000') }
     it { is_expected.to contain_class('keystone::service').with(
       'validate'       => true,
-      'admin_endpoint' => 'http://some.host:35357/v2.0'
+      'admin_endpoint' => 'http://some.host:5000/v2.0'
     )}
   end
 
@@ -888,13 +885,13 @@ describe 'keystone' do
       {
         :admin_token      => 'service_token',
         :validate_service => true,
-        :admin_endpoint   => 'http://some.host:35357'
+        :admin_endpoint   => 'http://some.host:5000'
       }
     end
 
     it { is_expected.to contain_class('keystone::service').with(
       'validate'       => true,
-      'admin_endpoint' => 'http://some.host:35357'
+      'admin_endpoint' => 'http://some.host:5000'
     )}
   end
 
